==> aws-solutions-konstruk.aws-kinesis-firehose-s3-kinesis-analytics-0.8.0.tar.gz: aws-solutions-konstruk.aws-kinesis-firehose-s3-kinesis-analytics-0.8.0/setup.py <==
import json
import setuptools

kwargs = json.loads("""
{
    "name": "aws-solutions-konstruk.aws-kinesis-firehose-s3-kinesis-analytics",
    "version": "0.8.0",
    "description": "CDK constructs for defining an interaction between an Amazon Kinesis Data Firehose delivery stream and (1) an Amazon S3 bucket, and (2) an Amazon Kinesis Data Analytics application.",
    "license": "Apache-2.0",
    "url": "https://github.com/awslabs/aws-solutions-konstruk.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "project_urls": {
        "Source": "https://github.com/awslabs/aws-solutions-konstruk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_solutions_konstruk.aws_kinesis_firehose_s3_kinesis_analytics",
        "aws_solutions_konstruk.aws_kinesis_firehose_s3_kinesis_analytics._jsii"
    ],
    "package_data": {
        "aws_solutions_konstruk.aws_kinesis_firehose_s3_kinesis_analytics._jsii": [
            "aws-kinesisfirehose-s3-and-kinesisanalytics@0.8.0.jsii.tgz"
        ],
        "aws_solutions_konstruk.aws_kinesis_firehose_s3_kinesis_analytics": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "jsii~=0.22.0",
        "publication>=0.0.3",
        "aws-cdk.aws-iam>=1.25.0, <1.26.0",
        "aws-cdk.aws-kinesis>=1.25.0, <1.26.0",
        "aws-cdk.aws-kinesisanalytics>=1.25.0, <1.26.0",
        "aws-cdk.aws-kinesisfirehose>=1.25.0, <1.26.0",
        "aws-cdk.aws-s3>=1.25.0, <1.26.0",
        "aws-cdk.core>=1.25.0, <1.26.0",
        "aws-solutions-konstruk.aws-kinesis-firehose-s3>=0.8.0, <0.9.0",
        "aws-solutions-konstruk.core>=0.8.0, <0.9.0"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Typing :: Typed",
        "License :: OSI Approved"
    ]
}
""")

with open('README.md') as fp:
    kwargs['long_description'] = fp.read()


setuptools.setup(**kwargs)

==> aws-solutions-konstruk.aws-kinesis-firehose-s3-kinesis-analytics-0.8.1.tar.gz: aws-solutions-konstruk.aws-kinesis-firehose-s3-kinesis-analytics-0.8.1/setup.py <==
import json
import setuptools

kwargs = json.loads("""
{
    "name": "aws-solutions-konstruk.aws-kinesis-firehose-s3-kinesis-analytics",
    "version": "0.8.1",
    "description": "CDK constructs for defining an interaction between an Amazon Kinesis Data Firehose delivery stream and (1) an Amazon S3 bucket, and (2) an Amazon Kinesis Data Analytics application.",
    "license": "Apache-2.0",
    "url": "https://github.com/awslabs/aws-solutions-konstruk.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "project_urls": {
        "Source": "https://github.com/awslabs/aws-solutions-konstruk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_solutions_konstruk.aws_kinesis_firehose_s3_kinesis_analytics",
        "aws_solutions_konstruk.aws_kinesis_firehose_s3_kinesis_analytics._jsii"
    ],
    "package_data": {
        "aws_solutions_konstruk.aws_kinesis_firehose_s3_kinesis_analytics._jsii": [
            "aws-kinesisfirehose-s3-and-kinesisanalytics@0.8.1.jsii.tgz"
        ],
        "aws_solutions_konstruk.aws_kinesis_firehose_s3_kinesis_analytics": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "jsii>=1.5.0, <2.0.0",
        "publication>=0.0.3",
        "aws-cdk.aws-iam>=1.40.0, <1.41.0",
        "aws-cdk.aws-kinesis>=1.40.0, <1.41.0",
        "aws-cdk.aws-kinesisanalytics>=1.40.0, <1.41.0",
        "aws-cdk.aws-kinesisfirehose>=1.40.0, <1.41.0",
        "aws-cdk.aws-s3>=1.40.0, <1.41.0",
        "aws-cdk.core>=1.40.0, <1.41.0",
        "aws-solutions-konstruk.aws-kinesis-firehose-s3>=0.8.1, <0.9.0",
        "aws-solutions-konstruk.core>=0.8.1, <0.9.0",
        "constructs>=3.0.2, <4.0.0"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Typing :: Typed",
        "License :: OSI Approved"
    ]
}
""")

with open('README.md') as fp:
    kwargs['long_description'] = fp.read()


setuptools.setup(**kwargs)
